import React from 'react';
import dayjs from 'dayjs';
import { Row, Col, Button, Form, Input, DatePicker } from 'antd';
import { ModalForm } from '@ant-design/pro-components';
import { postTaCheck, putTaCheck } from '@/service/tacheck';

export default (props) => {
  const { checkInfo, onChange } = props;

  const [open, setOpen] = React.useState(false);
  const [form] = Form.useForm();

  const title = checkInfo ? checkInfo.title : '点击编辑创建';
  const dateStr = checkInfo ? `${checkInfo.startDate} ~ ${checkInfo.endDate}` : '';

  const onFinish = async (values) => {
    const data = {
      ...values,
      startDate: dayjs(values.startDate).format('YYYY-MM-DD'),
      endDate: dayjs(values.endDate).format('YYYY-MM-DD'),
    }

    if (!checkInfo) {
      const res = await postTaCheck(data);
      onChange(res);
    } else {
      const res = await putTaCheck(checkInfo.checkId, data);
      onChange(res);
    }

    return true;
  }

  React.useEffect(() => {
    if (checkInfo) {
      form.setFieldsValue({
        ...checkInfo,
        startDate: dayjs(checkInfo.startDate),
        endDate: dayjs(checkInfo.endDate),
      });
    }
  }, [checkInfo]);

  return (
    <Row gutter={48}>
      <Col span={18}>
        <h2 style={{ textAlign: 'center' }} >{title}</h2>
        <Row>
          <Col span={8} offset={16}>{dateStr}</Col>
        </Row>
      </Col>
      <Col span={4}>
        <Button onClick={() => setOpen(true)}>编辑</Button>
      </Col>
      <ModalForm title="测评维护" open={open} width={480} form={form} onFinish={onFinish} onOpenChange={setOpen}>
          <Form.Item name="title" label="测评名称" required>
            <Input placeholder="请输入测评名称" />
          </Form.Item>
          <Form.Item name="startDate" label="开始时间" required>
            <DatePicker placeholder="请选择" style={{ width: '100%' }} />
          </Form.Item>
          <Form.Item name="endDate" label="结束时间" required>
            <DatePicker placeholder="请选择" style={{ width: '100%' }} />
          </Form.Item>
      </ModalForm>
    </Row>
  )
}
