import React, { useEffect, useState } from 'react';
import { Button, Card, Form, Input, Select } from 'antd';
import useBool from '@/utils/hooks/useBool';
import { postTdLocType, putTdLocType, getTdLocTypeById } from "@/service/tdloctype";
import { useSearchParams, useNavigate } from 'react-router-dom';

const formItemLayout = {
  labelCol: {
    xs: { span: 24 },
    sm: { span: 8 },
  },
  wrapperCol: {
    xs: { span: 24 },
    sm: { span: 16 },
  },
};
const tailFormItemLayout = {
  wrapperCol: {
    xs: {
      span: 24,
      offset: 0,
    },
    sm: {
      span: 16,
      offset: 8,
    },
  },
};

const { Option } = Select;

export default (props) => {

  const [loading, startLoading, cancelLoading] = useBool();
  const [submiting, startSubmit, cancelSubmit] = useBool();
  const [form] = Form.useForm();
  const navigate = useNavigate();
  const [searchParams] = useSearchParams();
  const id = searchParams.get("id");

  useEffect(() => {
    if (id) {
      getTdLocTypeById(id).then((res) => {
        form.setFieldsValue(res);
      });
    }
  }, [id]);

  console.log('id', id);

  const onFinish = (values) => {
    startSubmit();
    console.log('locType修改id', id);
    if (id) {
      // 修改
      putTdLocType(id, values).then((res) => {
        navigate(-1);
      }).catch(() => {
        cancelSubmit();
      });
    } else {
      // 新增
      postTdLocType(values).then((res) => {
        navigate(-1);
      }).catch(() => {
        cancelSubmit();
      });
    }
  }


  return (
    <Card loading={loading}>
      <Form onFinish={onFinish} form={form} {...formItemLayout} scrollToFirstError style={{ maxWidth: '1000px' }}>
        <Form.Item
          name="name"
          label="分类名称"
        >
          <Input />
        </Form.Item>
        <Form.Item
          name="desc"
          label="分类描述"
        >
          <Input />
        </Form.Item>

        <Form.Item
          name="sortNo"
          label="排序"
        >
          <Input />
        </Form.Item>


        <Form.Item
          name="status"
          label="状态"
        >
          <Select
            style={{ width: '100%' }}
            placeholder="请选择状态"
          >
            <Option key={0}>不正常</Option>
            <Option key={1}>正常</Option>
          </Select>
        </Form.Item>
        <Form.Item {...tailFormItemLayout}>
          <Button loading={submiting} type="primary" htmlType="submit">
            保存
          </Button>
          <Button style={{ marginLeft: '2em' }} onClick={() => navigate(-1)}>
            返回
          </Button>
        </Form.Item>
      </Form>
    </Card>
  )
}


